#
# spec file for package dbus-1-python3
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} <= 1140
%{!?python3_sitearch: %global python3_sitearch %(python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%{!?py3_ver: %global py3_ver %(python3 -c "import sys; version=str(sys.version_info[0]) + '.' + str(sys.version_info[1]); print(version)")}
%endif

Name:           dbus-1-python3
Version:        1.2.0
Release:        9.17
Summary:        Python bindings for D-Bus
License:        MIT
Group:          Development/Libraries/Python
Url:            http://www.freedesktop.org/wiki/Software/DBusBindings/
Source0:        http://dbus.freedesktop.org/releases/dbus-python/dbus-python-%{version}.tar.gz
#BuildRequires:  epydoc
BuildRequires:  fdupes
BuildRequires:  python3-2to3
BuildRequires:  python3-devel >= 3.2
%if 0%{?suse_version} && 0%{?suse_version} <= 1140
BuildRequires:  docutils
%else
BuildRequires:  python3-docutils
%endif
BuildRequires:  pkgconfig(dbus-1) >= 1.6.0
BuildRequires:  pkgconfig(dbus-glib-1)
Requires:       python3-xml
Requires:       dbus-1 >= %( echo `rpm -q --queryformat '%{VERSION}' dbus-1`)
Requires:       python(abi) = %{py3_ver}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
D-Bus python bindings for use with python programs.

%package -n dbus-1-python3-devel
Summary:        Python bindings for D-Bus
Group:          Development/Libraries/Python
Requires:       dbus-1-python3 = %{version}
Requires:       dbus-1 >= %( echo `rpm -q --queryformat '%{VERSION}' dbus-1`)
Requires:       dbus-1-devel >= %( echo `rpm -q --queryformat '%{VERSION}' dbus-1-devel`)

%description -n dbus-1-python3-devel
Developer files for Python bindings for D-Bus.

%prep
%setup -q -n dbus-python-%{version}

%build
2to3 -w -n .
export CFLAGS="%{optflags} -fstack-protector -fno-strict-aliasing -fPIC"
export PYTHON=python3
#api doc require epydoc that currently not avaliable for py3
%configure --docdir=%{_docdir}/dbus-1-python3 --disable-api-docs
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

# Remove libtool config files
rm -f %{buildroot}%{python3_sitearch}/*.la

# Install additional docs
install -pm 0644 AUTHORS COPYING ChangeLog %{buildroot}%{_docdir}/dbus-1-python3/
# Remove files that will be included in dbus-1-python-devel
rm -f %{buildroot}%{_docdir}/dbus-1-python3/{API_CHANGES.*,HACKING.*,PY3PORT.*,tutorial.*}

# Install devel docs (do it manually to fix also rpmlint warning "files-duplicate" with %%fdupes)
mkdir -p %{buildroot}%{_docdir}/dbus-1-python3-devel-doc
#skip api dir
cp -a doc/ examples/ %{buildroot}%{_docdir}/dbus-1-python3-devel-doc/
# Remove Makefile* (fix rpmlint warning "makefile-junk")
rm -f %{buildroot}%{_docdir}/dbus-1-python3-devel-doc/examples/Makefile*

#avoid conflicts with py2
mv %{buildroot}%{_includedir}/dbus-1.0/dbus/dbus-python.h \
   %{buildroot}%{_includedir}/dbus-1.0/dbus/dbus-python-%{py3_ver}.h
mv %{buildroot}%{_libdir}/pkgconfig/dbus-python.pc \
   %{buildroot}%{_libdir}/pkgconfig/dbus-python-%{py3_ver}.pc

%fdupes -s %{buildroot}

%files
%defattr(-,root,root,-)
%doc %{_docdir}/dbus-1-python3/
%{python3_sitelib}/*
%{python3_sitearch}/*

%files -n dbus-1-python3-devel
%defattr(-,root,root,-)
%doc %{_docdir}/dbus-1-python3-devel-doc/
#this files just to avoid confict
%{_includedir}/dbus-1.0/dbus/dbus-python-%{py3_ver}.h
%{_libdir}/pkgconfig/dbus-python-%{py3_ver}.pc

%changelog
* Mon Jun  3 2013 asterios.dramis@gmail.com
- Removed the %%{RELEASE} from the dbus-1 Requires: entries (fixes also Factory
  auto check).
* Sun Jun  2 2013 asterios.dramis@gmail.com
- Update to version 1.2.0:
  Dependencies:
  - libdbus 1.6 or later is now required.
  Enhancements:
  - Unicode Corrigendum 9: when used with a suitable version of libdbus
    (1.6.10 or later, or 1.7.2 or later), noncharacters in strings are
    now accepted
  Fixes:
  - Support DBusException('something with non—ASCII') under Python 2
    (Michael Vogt, smcv; fd.o #55899)
  - Correct some misleading wording in COPYING which was written under the
    assumption that libdbus could actually be relicensed to MIT/X11
    (Thiago Macieira)
  - Avoid variable-length arrays, because MSVC++ is still stuck in 1998
    (based on patches from Christoph Höger, fd.o #51725)
  - Remove unnecessary uses of stdint.h (fd.o #51725)
  - Add support for Unix compilers not supporting 'inline', for completeness
  - Use GObject.__class__ instead of GObjectMeta, which can no longer be
    imported from gi.repository.GObject in pygobject 3.8
  - Fix autoreconfiscation on Automake 1.13 (Marko Lindqvist, fd.o #59006)
- Removed libxml2-python3 runtime requirement (not needed).
* Mon Nov 19 2012 asterios.dramis@gmail.com
- Update to version 1.1.1:
  Dependencies:
  - libdbus 1.6 or later is now recommended. It is not strictly required yet.
  Fixes:
  - Validate UTF-8 according to the rules libdbus uses, falling back to our
    own (inefficient) implementation if not compiled against dbus >= 1.6
    (fdo#40817)
  - Under Python 3, in the absence of introspection or signature='...',
    pass dbus.ObjectPath or dbus.Signature arguments with the obvious
    signature 'o' or 'g', not 's'. This previously only worked in Python 2.
    (fdo#50740)
  From version 1.1.0:
  Deprecations:
  - dbus.gobject_service is deprecated. Use dbus.gi_service and PyGI in new
    code.
  API changes:
  - dbus.gobject_service works in legacy PyGObject 2 applications again,
    like it did before 1.0. The down side is that it doesn't work in all PyGI
    applications any more, unlike 1.0. In PyGI applications, depend on
    dbus-python >= 1.1 and use dbus.gi_service instead - its API is the same.
    (fdo#48904, deb#670516)
  - dbus.gobject_service has been removed from Python 3 builds altogether.
  Enhancements:
  - Use DBusBasicValue from libdbus 1.5, if available, rather than reinventing
    it
  Fixes:
  - Put sockets for the regression tests in /tmp, not the builddir, fixing
    test failures in a really long builddir (fdo#46747)
  - Fix a reference leak in dbus_py_variant_level_set (fdo#47108)
  - Modify AM_CHECK_PYTHON_HEADERS so the "another way" works with Python 3
* Sun May 27 2012 highwaystar.ru@gmail.com
- python3 package added
- api docs currently not built because there is no epydoc for py3
- dbus-python.h renamed to dbus-python-%%{py3_ver}.h
- шdbus-python.pc renamed to dbus-python-%%{py3_ver}.pc
